@@ -79,7 +79,7 @@ modulemd_module_index_finalize (GObject *object)
 static void
 modulemd_module_index_get_property (GObject *object,
                                     guint prop_id,
-                                    GValue *value,
+                                    GValue *UNUSED (value),
                                     GParamSpec *pspec)
 {
   switch (prop_id)
@@ -92,7 +92,7 @@ modulemd_module_index_get_property (GObject *object,
 static void
 modulemd_module_index_set_property (GObject *object,
                                     guint prop_id,
-                                    const GValue *value,
+                                    const GValue *UNUSED (value),
                                     GParamSpec *pspec)
 {
   switch (prop_id)
@@ -143,12 +143,9 @@ add_subdoc (ModulemdModuleIndex *self,
 {
   g_autoptr (GError) nested_error = NULL;
   g_autoptr (ModulemdModuleStream) stream = NULL;
-  g_autoptr (ModulemdModuleIndex) index = NULL;
-  g_autoptr (ModulemdPackagerV3) packager = NULL;
   g_autoptr (ModulemdTranslation) translation = NULL;
   g_autoptr (ModulemdObsoletes) obsoletes = NULL;
   g_autoptr (ModulemdDefaults) defaults = NULL;
-  g_autofree gchar *name = NULL;
   ModulemdYamlDocumentTypeEnum doctype =
     modulemd_subdocument_info_get_doctype (subdoc);
 
@@ -335,11 +332,11 @@ modulemd_module_index_update_from_parser (ModulemdModuleIndex *self,
           else
             {
               /* Initial parsing worked, parse further */
+              g_autoptr (GError) subdoc_error = NULL;
               if (!add_subdoc (
-                    self, subdoc, strict, autogen_module_name, error))
+                    self, subdoc, strict, autogen_module_name, &subdoc_error))
                 {
-                  modulemd_subdocument_info_set_gerror (subdoc, *error);
-                  g_clear_pointer (error, g_error_free);
+                  modulemd_subdocument_info_set_gerror (subdoc, subdoc_error);
                   /* Add to failures and ignore */
                   g_ptr_array_add (*failures, g_steal_pointer (&subdoc));
                   all_passed = FALSE;
@@ -1370,7 +1367,6 @@ modulemd_module_index_upgrade_defaults (ModulemdModuleIndex *self,
   gpointer value;
   g_autoptr (ModulemdModule) module = NULL;
   g_autoptr (ModulemdDefaults) defaults = NULL;
-  ModulemdDefaultsVersionEnum returned_mdversion = MD_DEFAULTS_VERSION_UNSET;
   g_autoptr (GError) nested_error = NULL;
 
   if (mdversion < self->defaults_mdversion)
@@ -1409,9 +1405,8 @@ modulemd_module_index_upgrade_defaults (ModulemdModuleIndex *self,
 
       g_object_ref (defaults);
 
-      returned_mdversion = modulemd_module_set_defaults (
-        module, defaults, self->defaults_mdversion, &nested_error);
-      if (returned_mdversion != mdversion)
+      if (mdversion != modulemd_module_set_defaults (
+                         module, defaults, mdversion, &nested_error))
         {
           g_propagate_prefixed_error (
             error,
@@ -1432,7 +1427,7 @@ modulemd_module_index_upgrade_defaults (ModulemdModuleIndex *self,
 gboolean
 modulemd_module_index_add_translation (ModulemdModuleIndex *self,
                                        ModulemdTranslation *translation,
-                                       GError **error)
+                                       GError **UNUSED (error))
 {
   g_return_val_if_fail (MODULEMD_IS_MODULE_INDEX (self), FALSE);
 
@@ -1444,6 +1439,26 @@ modulemd_module_index_add_translation (ModulemdModuleIndex *self,
 }
 
 
+static void
+clear_xmds (gpointer key, gpointer value, gpointer user_data)
+{
+  MODULEMD_INIT_TRACE ();
+
+  g_return_if_fail (MODULEMD_IS_MODULE (value));
+
+  modulemd_module_clear_xmds (MODULEMD_MODULE (value));
+}
+
+
+void
+modulemd_module_index_clear_xmds (ModulemdModuleIndex *self)
+{
+  MODULEMD_INIT_TRACE ();
+
+  g_hash_table_foreach (self->modules, clear_xmds, NULL);
+}
+
+
 gboolean
 modulemd_module_index_merge (ModulemdModuleIndex *from,
                              ModulemdModuleIndex *into,
